Businessweek - Business News, Stock market & Financial Advice

Sign in with Facebook Or use your Businessweek account
Email Password Forgot password? Remember me

Already a Bloomberg.com user?

Sign in with the same account.

Don't have an account? Sign up.

Help! I can't access my account.

This site uses cookies. By continuing to browse the site you are agreeing to our use of cookies. X
Bloomberg Businessweek

## Businessweek

LIMITED-TIME OFFER SUBSCRIBE NOW
Thank you for confirming your email address. You are now subscribed to the Businessweek Daily Newsletter.

©2013 Bloomberg LP. All rights reserved. Made in NYC. Privacy Policy
We are sorry, the article you requested is no longer available.

You are now being redirected to the home page for the latest articles.

## Anniversary Issue: 85 Years, 85 Ideas

Our list of the most disruptive ideas of the past 85 years

## Has Oculus Conquered the Virtual-Reality Vomit Problem?

By Joshua Brustein

## The Little Kano That Could: A $150 Computer for Kids

By Ashlee Vance

- #### Anniversary Issue: 85 Years, 85 Ideas

- #### Has Oculus Conquered the Virtual-Reality Vomit Problem?

- #### The Little Kano That Could: A $150 Computer for Kids

### Technology

- #### Sony Hackers Were Inside the Company Network for a Long Time

- ##### GPS as We Know It Happened Because of Ronald Reagan

- ##### Google May Be the Big Winner in the L.A. School IPad Scandal

### Companies

- #### Glock vs. Smith & Wesson: A Shootout for the Pentagon's New Pistol

- ##### A Car for Christmas? It Really Happens, With a Bow on Top

- ##### Luxury Hotels Spring Up Across China

### Global Economics

- #### U.S. GDP Is Just a State of Mind

- ##### Oil Speculators (Mostly) Saw the Massive Price Drop Coming

- ##### New Storm Threatens Philippines, the Most Disaster-Prone Country

### Politics

- #### The Eric Garner Case Weakens the Argument for Police Body Cameras

- ##### Obamacare's Future: Cancer Patients Paying More for Medication

- ##### Get Ready for Big Increase in Mortgage Payments

### Lifestyle

- #### Emirates Airlines Wanted More for Its World Cup Dollars

- ##### How NBC's The Voice Sold 20 Million Songs Without a Single Star

- ##### The Internet Knows What Gifts You Really Want

### Small Business

- #### Hoarder Nation: America's Self-Storage Industry Is Booming

- ##### Roy Choi Wants to Reinvent Fast Food

- ##### In Ferguson's Violence, Small Business Owners Are the Biggest Losers

### The Orion Launch

##### NASA's First Small Step to Mars

A test flight of NASA's Orion capsule is meant to demonstrate that the technical expertise needed to send humans to Mars is in hand.

### Pets

- ##### The Birth of Kitty Litter

### The Law

- ##### How Billable Hours Changed the Legal Profession

### Markets

- ##### One of the Most Famous Rules of Investing Might Be Totally Wrong

### Innovation & Design

- #### Why NASA's Orion Spacecraft Looks So Familiar

- ##### The One Mathematical Formula That Helped Create the Digital Age

- ##### Facebook's Weird, Warm Data Centers Reach the Mainstream

### Business Schools

- #### New Expert Investigators Won’t Solve the Campus Rape Problem

- ##### How to Get More Respect From Your Boss

- ##### Jobs Boom in Cities Where People Obsessively Network

- Tools
- Rankings and Profiles
- MBA Programs
- School Finder
- B-School, Explained

### Watch

Play

#### Steve Wozniak Debunks One of Apple's Biggest Myths

Dec. 4 (Bloomberg) –- For its 85th anniversary, Bloomberg Businessweek chronicles the most disruptive ideas of the past 85 years. In 1976, The Apple 1 computer goes on sale for a retail price of $666.66. Steve Wozniak, who co-founded Apple with Steve Jobs and designed that product, remembers the early days. (Video by Brandon Lisy) (Source: Bloomberg)

- Video

  #### GOP Launches State Lawsuits in Immigration Strategy

- Video

  #### The Streaming Music Service Taylor Swift Wants to Be on

### Feed Headlines

- Most Popular
- Bloomberg
- Recent

- Glock vs. Smith & Wesson: A Shootout for the Pentagon's New Pistol Contract
- NASA Is Launching a Spacecraft That Will Take Humans to Mars
- Steve Wozniak on Apple, the Computer Revolution, and Working With Steve Jobs
- Experts: Sony Hackers Were Inside the Company Network for a Long Time
- Why NASA's Orion Spacecraft Looks So Familiar
- Gone in an Instant: How One NBA Player Lost $110M
- The Jet Engine: No Invention of the Past 85 Years Had a Greater Impact on the World
- Princeton Has a Shadow Fraternity System Nobody Controls

- U.S. Stocks Drop on ECB Stimulus Plans as Energy Slumps
- ECB Preparing Broad Stimulus Plan, All Assets but Gold on the Table for Purchase
- Putin Says Crimea Sacred, Attacks U.S., EU Over Ukraine
- Cleveland Police Use Unreasonable Force in Shootings; U.S. Finding Comes After Death of Boy and as Protests Swell
- House Passes $577.1 Billion Defense Policy Bill, Spurning Cuts
- Siege in West Iraq Shows Failure to Reverse Islamic State Gains
- Shorts Bypass Exxon for Norway as Favored Oil-Rout Play
- Sharpton on Garner: 'After 11 Times of "I Can’t Breathe," When Does Your Humanity Kick In?'

- Has Oculus Finally Conquered the Virtual-Reality Vomit Problem?
- Banning Drinking Won't Stop Campus Rape
- The Newest Amazon Gizmos: Diapers and Baby Wipes
- The Little Kano That Could: A $150 Computer for Kids
- Why NASA's Orion Spacecraft Looks So Familiar
- Aaron Sorkin on TV’s Past, Present, and Future
- Congressmen to Obama Administration: Look Harder at Shady For-Profit College Deal
- Princeton Has a Shadow Fraternity System Nobody Controls
- It's Not a Waste of Time to Go to College When You're Older
- 85th Anniversary Issue: Editor's Letter

### Last Updated: 04:52 pm Market Summary

- US
- Europe
- Asia

S&P500 | 2071.92 | -2.41
DJIA | 17900.1 | -12.52
NASDAQ | 4769.438 | -5.034

Stoxx 50 | 3191.25 | -56.47
FTSE 100 | 6679.37 | -37.26
DAX | 9851.35 | -120.44

Nikkei | 17887.21 | 166.78
Topix | 1440.6 | 10.85
Hang Seng | 23832.56 | 403.94

#### Company Lookup

### Newsletter Signup

Sample copy
Businessweek.com, on behalf of itself and select partners, may send me offers and promotions.
Bloomberg, on behalf of itself and select partners, may send me offers and promotions.

Thank you for subscribing to our Daily Newsletter. You will receive a confirmation email shortly at .

### Ads by Google

### Post a Job Jobs

- Business Development jobs
- Design jobs
- Entertainment jobs
- Environmental jobs
- Executive jobs
- Healthcare jobs
- Legal jobs
- Management jobs
- Marketing jobs
- Real Estate jobs
- Retail jobs
- Sales jobs

Simply Hired View all jobs

### Sponsored Links

Buy a link now!

### SPECIAL ADVERTISING

- Innovation Fueled by Insight
- World Changers

Continue to Businessweek